@@ -28,8 +28,11 @@ from Products.CMFCore.utils import UniqueObject
 from Products.CMFCore.utils import getToolByName
 
 import zLOG
-from config import SEPARATOR, PROPS, ALLPROPS, NONATPROPS, TYPEMAP
-from Globals import DTMLFile
+from config import SEPARATOR, PROPS, ALLPROPS, NONATPROPS, TYPEMAP, DEFAULT_ENCODING
+try:
+    from App.special_dtml import DTMLFile
+except:
+    from Globals import DTMLFile
 
 class ContentExporter(UniqueObject, SimpleItem):
     """An old school Product for plone 2 that sucks out content into plone 3
@@ -40,10 +43,11 @@ class ContentExporter(UniqueObject, SimpleItem):
        If archetypes are found their schema data is added to the properties.
     """  
 
-    __implements__ = (
-        SimpleItem.__implements__,
-    )
-
+    try:
+        __implements__ = (SimpleItem.__implements__,)
+    except:
+        pass
+        
     meta_type = 'Content Exporter Tool'
     plone_tool = 1
     id = 'portal_exportcontent'
@@ -67,12 +71,31 @@ class ContentExporter(UniqueObject, SimpleItem):
     manage_export = PageTemplateFile(os.path.join('www','exportContentMigrator.pt'), globals(),
                                    __name__='manage_export')
 
-
     def __init__(self):
         """ Set savepath and log """
-        self.savepath = os.path.join(INSTANCE_HOME, 'var', 'structure')
+        self.savepath = self.get_var_path()
         self.out = []
 
+
+    def get_var_path(self):
+        """ Find var if buildout or old style zope layout or
+            test runner where instance home is the buildout-cache!
+        """
+        var = os.path.join(INSTANCE_HOME, 'var')
+        if os.path.exists(var):
+            return os.path.join(var,'structure')
+        for folder in ['parts','buildout-cache']:
+            parts = INSTANCE_HOME.find(folder)
+            if parts>-1:
+                if os.path.exists(os.path.join(INSTANCE_HOME[0:parts], 'var')):
+                    return os.path.join(var,'structure')
+                else:
+                    return os.path.join(INSTANCE_HOME[0:parts], 'structure')
+        for var in ['/tmp','\\temp']:
+            if os.path.exists(var):
+                return os.path.join(var,'structure')
+
+
     security.declareProtected( ManagePortal, 'manage_runExport' )
     def manage_runExport(self, portal=None, root=''):
         """ run the export if root submitted -
@@ -132,6 +155,8 @@ class ContentExporter(UniqueObject, SimpleItem):
                 if type(data) in StringTypes:
                     try:
                         os.write(ofd,data)
+                    except UnicodeEncodeError:
+                        os.write(ofd, data.encode(DEFAULT_ENCODING))
                     except:
                         binary = 1
                 else:
@@ -326,7 +351,7 @@ class ContentExporter(UniqueObject, SimpleItem):
         self.workflow_tool = getToolByName(portal, 'portal_workflow')
         portalname = portal.getId()
         self.lenportal = len(portalname) + 1
-        self.out = []
+        self.out = ['Log started at %s' % DateTime()]
 
         # Give this a request attribute since some methods expect it
         # and it is not available when used via current plone 
@@ -338,14 +363,14 @@ class ContentExporter(UniqueObject, SimpleItem):
                 shutil.rmtree(self.savepath)
             os.mkdir(self.savepath)
         except:
-            self.out = ['Failed to create structure folder in zope/var',]
-            return
+            self.out.append('Failed to create structure folder in %s' % self.savepath)
+            return self.out
 
         if users:
-            if hasattr(portal,'REQUEST'):
+            try:
                 self.export_users(portal)
-            else:
-                self.out.append('Sorry users couldnt be exported because a REQUEST object is needed')
+            except:
+                self.out.append('Sorry not all users could be exported.')
 
         if not root.startswith('/'):
             root = '/%s' % root
