@@ -17,7 +17,7 @@ from Products.CMFCore.exportimport.content import StructureFolderWalkingAdapter
 
 from ilrt.contentmigrator.ContentMigrator.config import SEPARATOR
 from ilrt.contentmigrator.ContentMigrator.config import PROPS
-from ilrt.contentmigrator.browser.contentexporter import ContentExporterView
+from ilrt.contentmigrator.exportimport.contentexporter import ContentExporterView
 from ilrt.contentmigrator.exportimport.utils import atconvert
 from ilrt.contentmigrator.exportimport.pas import import_users
 
@@ -110,9 +110,9 @@ class SFWA(StructureFolderWalkingAdapter):
     implements(IFilesystemExporter, IFilesystemImporter)
 
     def __init__(self, context):
-        request = getattr(self,'REQUEST',{})
         self.out = []
         self.context = context
+        request = getattr(context,'REQUEST',{})
         self.reindex = request.get('reindex','item')
         if MIGRATE_WORKFLOW:
             self.wfmt = WorkflowMigrationView(context,request)
@@ -183,11 +183,11 @@ class SFWA(StructureFolderWalkingAdapter):
         try:
             for object_id, portal_type in ours:
                 if object_id not in existing:
-                    try:
-                        object = self._makeInstance(object_id, portal_type,
+                    #try:
+                    object = self._makeInstance(object_id, portal_type,
                                                     subdir, import_context)
-                    except:
-                        object = None
+                    #except:
+                    #    object = None
                     if object is None:
                         self.out.append("Couldn't make instance: %s/%s" %
                                        (subdir, object_id))
@@ -200,8 +200,7 @@ class SFWA(StructureFolderWalkingAdapter):
                 sfwa.import_(import_context, subdir)
                 self.out.extend(sfwa.out)
             if getattr(self, 'reindex', 'item') == 'all':
-                catalog = getToolByName(context, 'portal_catalog')
-                catalog.refreshCatalog(clear=1)
+                self.refreshCatalog()
         except ValueError:
             err = 'Aborted import due to format error for %s .objects' % subdir
             self.out.append(err)
@@ -215,7 +214,8 @@ class SFWA(StructureFolderWalkingAdapter):
 
         try:
             tool.constructContent(portal_type, context, id)
-        except ValueError: # invalid type
+        except ValueError, err: # invalid type
+            self.out.append(str(err))
             return None
 
         obj = context._getOb(id)
@@ -233,7 +233,7 @@ class SFWA(StructureFolderWalkingAdapter):
                 content_type = obj.getProperty('format', obj.getProperty('ContentType',''))
                 if data:
                     if portal_type == 'Image' or content_type.startswith('image'):
-                        obj.setImage(data, content_type)
+                        obj.setImage(data) #plone 4 doesnt take content_type arg
                     else:
                         obj.setFile(data)
             else:
@@ -398,3 +398,26 @@ class SFWA(StructureFolderWalkingAdapter):
                         setattr(obj, key, value)
         return
 
+    def refreshCatalog(self):
+        """ Taken from ZCatalog but with metadata preserved -
+            re-index everything we can find
+            TODO: see if this really makes a difference from
+            catalog.refreshCatalog()
+        """
+        catalog = getToolByName(self.context, 'portal_catalog')
+        cat = catalog._catalog
+        paths = cat.paths.values()
+        paths = tuple(paths)
+        cat.clear()
+        num_objects = len(paths)
+        for i in xrange(num_objects):
+            p = paths[i]
+            obj = catalog.resolve_path(p)
+            if obj is None:
+                obj = catalog.resolve_url(p, catalog.REQUEST)
+            if obj is not None:
+                try:
+                    catalog.catalog_object(obj, p, update_metadata=0)
+                except ConflictError:
+                    pass
+
